@@ -93,10 +93,7 @@ async def test_meta_api_synchronization():
         print('Submitting pending order')
         result = await connection.create_limit_buy_order('GBPUSD', 0.07, 1.0, 0.9, 2.0, 'comm',
                                                          'TE_GBPUSD_7hyINWqAlE')
-        if result['description'] == 'TRADE_RETCODE_DONE':
-            print('Trade successful')
-        else:
-            print('Trade failed with ' + result['description'] + ' error')
+        print('Trade successful, result code is ' + result.stringCode)
 
         # finally, undeploy account after the test
         print('Undeploying MT4 account so that it does not consume any unwanted resources')
