@@ -3,6 +3,8 @@ from .models import MetatraderAccountInformation, MetatraderPosition, Metatrader
     MetatraderSymbolSpecification, MetatraderSymbolPrice
 import functools
 from typing import List
+import asyncio
+from threading import Timer
 
 
 class TerminalState(SynchronizationListener):
@@ -101,12 +103,6 @@ class TerminalState(SynchronizationListener):
     async def on_connected(self):
         """Invoked when connection to MetaTrader terminal established."""
         self._connected = True
-        self._accountInformation = None
-        self._positions = []
-        self._orders = []
-        self._specifications = []
-        self._specificationsBySymbol = {}
-        self._pricesBySymbol = {}
 
     async def on_disconnected(self):
         """Invoked when connection to MetaTrader terminal terminated."""
@@ -114,12 +110,18 @@ class TerminalState(SynchronizationListener):
         self._connectedToBroker = False
 
     async def on_broker_connection_status_changed(self, connected: bool):
-        """Invoked when broker connection satus have changed.
+        """Invoked when broker connection status have changed.
 
         Args:
             connected: Whether MetaTrader terminal is connected to broker.
         """
+        def disconnect():
+            asyncio.run(self.on_disconnected())
         self._connectedToBroker = connected
+        if hasattr(self, '_status_timer'):
+            self._status_timer.cancel()
+        self._status_timer = Timer(60, disconnect)
+        self._status_timer.start()
 
     async def on_account_information_updated(self, account_information: MetatraderAccountInformation):
         """Invoked when MetaTrader account information is updated.
